from tcsoa.gen.WProxy._2014_10.services import ProxyLinkService as imp0
from tcsoa.base import TcService


class ProxyLinkService(TcService):
    createProxyLink = imp0.createProxyLink
